@@ -7,3 +7,5 @@ from pymupdf import _as_pdf_page
 from pymupdf import _log_items
 from pymupdf import _log_items_active
 from pymupdf import _log_items_clear
+from pymupdf import __version__
+from pymupdf import __doc__
